@@ -5,9 +5,9 @@ from sqlalchemy.orm import scoped_session, sessionmaker
 from uti.confi import Var
 
 def start() -> scoped_session:
-    dbi_uri=Var.DB_URL
-    dbi_uri="postgresql://"+dbi_uri[dbi_uri.index("//")+1:len(dbi_uri)]
-    engine = create_engine()
+    dbi_url=Var.DB_URL
+    dbi_url="postgresql://"+dbi_url[dbi_url.index("//")+1:len(dbi_url)]
+    engine = create_engine(dbi_url)
     BASE.metadata.bind = engine
     BASE.metadata.create_all(engine)
     return scoped_session(sessionmaker(bind=engine, autoflush=False))
